@@ -4,8 +4,8 @@
 
 ;; Author: Jen-Chieh Shen
 ;; URL: https://github.com/emacs-vs/vs-dark-theme
-;; Package-Version: 20260101.1429
-;; Package-Revision: ce1442aa8ee8
+;; Package-Version: 20260204.1514
+;; Package-Revision: e0d73e1a7e52
 ;; Package-Requires: ((emacs "24.1"))
 ;; Keywords: faces
 
@@ -193,6 +193,8 @@
  `(ahs-face-unfocused                ((t :background "#0E3056" :box (:line-width (-1 . -1) :style pressed-button :color "#525D68"))))
  `(ahs-definition-face-unfocused     ((t :background "#0E3056" :box (:line-width (-1 . -1) :style pressed-button :color "#525D68"))))
 
+ `(jcs-echobar-default ((t :foreground "#B2B2B2")))
+
  `(tab-line     ((t :background "#292929")))
  `(tab-line-tab ((t :background "#292929")))
 
@@ -216,14 +218,28 @@
 
  `(region-occurrences-highlighter-face ((t :background "#113D6F")))
 
- `(whitespace-indentation ((t :background "grey20" :foreground "aquamarine3")))
- `(whitespace-trailing    ((t :background "grey20" :foreground "red")))
+ `(whitespace-space       ((t :background "#1E1E1E" :foreground "#185A67")))
+ `(whitespace-tab         ((t :background "#1E1E1E" :foreground "#185A67")))
+ `(whitespace-indentation ((t :background "#1E1E1E" :foreground "#185A67")))
+ `(whitespace-trailing    ((t :background "#1E1E1E" :foreground "#CD4941")))
 
  `(highlight-numbers-number ((t :foreground "#9BCEA3")))
 
  `(modablist-select-face ((t :box (:line-width (-1 . -1) :color "#65A7E2" :style nil))))
  `(modablist-insert-face ((t :background "#565136" :box (:line-width (-1 . -1) :color "#65A7E2" :style nil))))
 
+ `(success ((t :foreground "#79BC83" :bold t)))
+ `(warning ((t :foreground "#D8960E" :bold t)))
+ `(error   ((t :foreground "#E6655C" :bold t)))
+
+ `(flycheck-info    ((t :underline (:style wave :color "#79BC83"))))
+ `(flycheck-warning ((t :underline (:style wave :color "#D8960E"))))
+ `(flycheck-error   ((t :underline (:style wave :color "#E6655C"))))
+
+ `(flymake-note    ((t :underline (:style wave :color "#79BC83"))))
+ `(flymake-warning ((t :underline (:style wave :color "#D8960E"))))
+ `(flymake-error   ((t :underline (:style wave :color "#E6655C"))))
+
  `(lsp-flycheck-info-unnecessary-face    ((t :inherit flycheck-info)))
  `(lsp-flycheck-warning-unnecessary-face ((t :inherit flycheck-warning)))
  `(lsp-flycheck-error-unnecessary-face   ((t :inherit flycheck-error)))
@@ -235,24 +251,22 @@
  `(dap-ui-breakpoint-verified-fringe ((t :foreground "#E71F2D")))
  `(breakpoint-disabled               ((t :foreground "#C55159")))
 
- `(success ((t :foreground "#10CA00" :bold t)))
- `(warning ((t :foreground "#F9983A" :bold t)))
- `(error   ((t :foreground "#DF655D" :bold t)))
-
- `(flycheck-info    ((t :underline (:style wave :color "#10CA00"))))
- `(flycheck-warning ((t :underline (:style wave :color "#F9983A"))))
- `(flycheck-error   ((t :underline (:style wave :color "#DF655D"))))
-
- `(sideline-default ((t :foreground "yellow")))
+ `(sideline-default ((t :foreground "#CBCD0E")))
  `(sideline-backend ((t :background "#2B2B2B" :foreground "#9B9B9B")))
 
- `(sideline-flycheck-info    ((t :foreground "#10CA00" :bold t)))
- `(sideline-flycheck-warning ((t :foreground "#F9983A" :bold t)))
- `(sideline-flycheck-error   ((t :foreground "#DF655D" :bold t)))
+ `(sideline-lsp-code-action ((t :foreground "#CBCD0E")))
 
- `(sideline-flymake-note    ((t :foreground "#10CA00" :bold t)))
- `(sideline-flymake-warning ((t :foreground "#F9983A" :bold t)))
- `(sideline-flymake-error   ((t :foreground "#DF655D" :bold t)))
+ `(sideline-flycheck-info    ((t :foreground "#79BC83" :bold t)))
+ `(sideline-flycheck-warning ((t :foreground "#D8960E" :bold t)))
+ `(sideline-flycheck-error   ((t :foreground "#E6655C" :bold t)))
+
+ `(sideline-flymake-note    ((t :foreground "#79BC83" :bold t)))
+ `(sideline-flymake-warning ((t :foreground "#D8960E" :bold t)))
+ `(sideline-flymake-error   ((t :foreground "#E6655C" :bold t)))
+
+ `(isearch        ((t :background "#4F5F73" :box (:line-width (-1 . -1) :style pressed-button :color "#525D68"))))
+ `(isearch-fail   ((t :background "#8C4040" :box (:line-width (-1 . -1) :style pressed-button :color "#525D68"))))
+ `(lazy-highlight ((t :background "#453B32" :box (:line-width (-1 . -1) :style pressed-button :color "#525D68"))))
 
  `(diff-added   ((t :background "#0F6B0F")))
  `(diff-removed ((t :background "#A91111")))
@@ -313,8 +327,7 @@
 
  `(define-it-pop-tip-color ((t :background "#2A2D38")))
 
- `(preview-it-background ((t :background "#2A2D38")))
- )
+ `(preview-it-background ((t :background "#2A2D38"))))
 
 (custom-theme-set-variables
  'vs-dark
